# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SyncTriggerResponse"]


class SyncTriggerResponse(BaseModel):
    error: Optional[str] = None

    last_sync: Optional[datetime] = FieldInfo(alias="lastSync", default=None)

    record_count: Optional[int] = FieldInfo(alias="recordCount", default=None)

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .root import (
    RootResource,
    AsyncRootResource,
    RootResourceWithRawResponse,
    AsyncRootResourceWithRawResponse,
    RootResourceWithStreamingResponse,
    AsyncRootResourceWithStreamingResponse,
)
from .sync import (
    SyncResource,
    AsyncSyncResource,
    SyncResourceWithRawResponse,
    AsyncSyncResourceWithRawResponse,
    SyncResourceWithStreamingResponse,
    AsyncSyncResourceWithStreamingResponse,
)
from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)
from .schools import (
    SchoolsResource,
    AsyncSchoolsResource,
    SchoolsResourceWithRawResponse,
    AsyncSchoolsResourceWithRawResponse,
    SchoolsResourceWithStreamingResponse,
    AsyncSchoolsResourceWithStreamingResponse,
)

__all__ = [
    "HealthResource",
    "AsyncHealthResource",
    "HealthResourceWithRawResponse",
    "AsyncHealthResourceWithRawResponse",
    "HealthResourceWithStreamingResponse",
    "AsyncHealthResourceWithStreamingResponse",
    "RootResource",
    "AsyncRootResource",
    "RootResourceWithRawResponse",
    "AsyncRootResourceWithRawResponse",
    "RootResourceWithStreamingResponse",
    "AsyncRootResourceWithStreamingResponse",
    "SchoolsResource",
    "AsyncSchoolsResource",
    "SchoolsResourceWithRawResponse",
    "AsyncSchoolsResourceWithRawResponse",
    "SchoolsResourceWithStreamingResponse",
    "AsyncSchoolsResourceWithStreamingResponse",
    "SyncResource",
    "AsyncSyncResource",
    "SyncResourceWithRawResponse",
    "AsyncSyncResourceWithRawResponse",
    "SyncResourceWithStreamingResponse",
    "AsyncSyncResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SchoolSearchParams"]


class SchoolSearchParams(TypedDict, total=False):
    q: Required[str]
    """Search query"""

    limit: int
    """Results per page (default: 20, max: 100)"""

    page: int
    """Page number (default: 1)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["HealthCheckResponse"]


class HealthCheckResponse(BaseModel):
    status: Optional[str] = None

    timestamp: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    school_list_params,
    school_search_params,
    school_by_city_params,
    school_by_status_params,
    school_by_suburb_params,
    school_by_authority_params,
)
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.school_list_response import SchoolListResponse
from ..types.school_search_response import SchoolSearchResponse
from ..types.school_retrieve_response import SchoolRetrieveResponse

__all__ = ["SchoolsResource", "AsyncSchoolsResource"]


class SchoolsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SchoolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/et0and/schools-sdk-python#accessing-raw-response-data-eg-headers
        """
        return SchoolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SchoolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/et0and/schools-sdk-python#with_streaming_response
        """
        return SchoolsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        school_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolRetrieveResponse:
        """
        Get school by School ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not school_id:
            raise ValueError(f"Expected a non-empty value for `school_id` but received {school_id!r}")
        return self._get(
            f"/v1/schools/id/{school_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchoolRetrieveResponse,
        )

    def list(
        self,
        *,
        authority: str | Omit = omit,
        city: str | Omit = omit,
        limit: int | Omit = omit,
        name: str | Omit = omit,
        org_type: str | Omit = omit,
        page: int | Omit = omit,
        status: str | Omit = omit,
        suburb: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolListResponse:
        """
        Get all schools with filtering

        Args:
          authority: Filter by education authority

          city: Filter by city (partial match)

          limit: Results per page (default: 20, max: 100)

          name: Filter by school name (partial match)

          org_type: Filter by organization type

          page: Page number (default: 1)

          status: Filter by school status

          suburb: Filter by suburb (partial match)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/schools",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "authority": authority,
                        "city": city,
                        "limit": limit,
                        "name": name,
                        "org_type": org_type,
                        "page": page,
                        "status": status,
                        "suburb": suburb,
                    },
                    school_list_params.SchoolListParams,
                ),
            ),
            cast_to=SchoolListResponse,
        )

    def by_authority(
        self,
        authority: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by authority

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not authority:
            raise ValueError(f"Expected a non-empty value for `authority` but received {authority!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/schools/authority/{authority}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_authority_params.SchoolByAuthorityParams,
                ),
            ),
            cast_to=NoneType,
        )

    def by_city(
        self,
        city: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by city

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not city:
            raise ValueError(f"Expected a non-empty value for `city` but received {city!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/schools/city/{city}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_city_params.SchoolByCityParams,
                ),
            ),
            cast_to=NoneType,
        )

    def by_status(
        self,
        status: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by status

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not status:
            raise ValueError(f"Expected a non-empty value for `status` but received {status!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/schools/status/{status}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_status_params.SchoolByStatusParams,
                ),
            ),
            cast_to=NoneType,
        )

    def by_suburb(
        self,
        suburb: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by suburb

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not suburb:
            raise ValueError(f"Expected a non-empty value for `suburb` but received {suburb!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/schools/suburb/{suburb}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_suburb_params.SchoolBySuburbParams,
                ),
            ),
            cast_to=NoneType,
        )

    def search(
        self,
        *,
        q: str,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolSearchResponse:
        """
        Full-text search schools by name

        Args:
          q: Search query

          limit: Results per page (default: 20, max: 100)

          page: Page number (default: 1)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/schools/search",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "q": q,
                        "limit": limit,
                        "page": page,
                    },
                    school_search_params.SchoolSearchParams,
                ),
            ),
            cast_to=SchoolSearchResponse,
        )


class AsyncSchoolsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSchoolsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/et0and/schools-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSchoolsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSchoolsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/et0and/schools-sdk-python#with_streaming_response
        """
        return AsyncSchoolsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        school_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolRetrieveResponse:
        """
        Get school by School ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not school_id:
            raise ValueError(f"Expected a non-empty value for `school_id` but received {school_id!r}")
        return await self._get(
            f"/v1/schools/id/{school_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchoolRetrieveResponse,
        )

    async def list(
        self,
        *,
        authority: str | Omit = omit,
        city: str | Omit = omit,
        limit: int | Omit = omit,
        name: str | Omit = omit,
        org_type: str | Omit = omit,
        page: int | Omit = omit,
        status: str | Omit = omit,
        suburb: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolListResponse:
        """
        Get all schools with filtering

        Args:
          authority: Filter by education authority

          city: Filter by city (partial match)

          limit: Results per page (default: 20, max: 100)

          name: Filter by school name (partial match)

          org_type: Filter by organization type

          page: Page number (default: 1)

          status: Filter by school status

          suburb: Filter by suburb (partial match)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/schools",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "authority": authority,
                        "city": city,
                        "limit": limit,
                        "name": name,
                        "org_type": org_type,
                        "page": page,
                        "status": status,
                        "suburb": suburb,
                    },
                    school_list_params.SchoolListParams,
                ),
            ),
            cast_to=SchoolListResponse,
        )

    async def by_authority(
        self,
        authority: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by authority

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not authority:
            raise ValueError(f"Expected a non-empty value for `authority` but received {authority!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/schools/authority/{authority}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_authority_params.SchoolByAuthorityParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def by_city(
        self,
        city: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by city

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not city:
            raise ValueError(f"Expected a non-empty value for `city` but received {city!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/schools/city/{city}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_city_params.SchoolByCityParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def by_status(
        self,
        status: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by status

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not status:
            raise ValueError(f"Expected a non-empty value for `status` but received {status!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/schools/status/{status}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_status_params.SchoolByStatusParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def by_suburb(
        self,
        suburb: str,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get schools by suburb

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not suburb:
            raise ValueError(f"Expected a non-empty value for `suburb` but received {suburb!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/schools/suburb/{suburb}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    school_by_suburb_params.SchoolBySuburbParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def search(
        self,
        *,
        q: str,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SchoolSearchResponse:
        """
        Full-text search schools by name

        Args:
          q: Search query

          limit: Results per page (default: 20, max: 100)

          page: Page number (default: 1)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/schools/search",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "q": q,
                        "limit": limit,
                        "page": page,
                    },
                    school_search_params.SchoolSearchParams,
                ),
            ),
            cast_to=SchoolSearchResponse,
        )


class SchoolsResourceWithRawResponse:
    def __init__(self, schools: SchoolsResource) -> None:
        self._schools = schools

        self.retrieve = to_raw_response_wrapper(
            schools.retrieve,
        )
        self.list = to_raw_response_wrapper(
            schools.list,
        )
        self.by_authority = to_raw_response_wrapper(
            schools.by_authority,
        )
        self.by_city = to_raw_response_wrapper(
            schools.by_city,
        )
        self.by_status = to_raw_response_wrapper(
            schools.by_status,
        )
        self.by_suburb = to_raw_response_wrapper(
            schools.by_suburb,
        )
        self.search = to_raw_response_wrapper(
            schools.search,
        )


class AsyncSchoolsResourceWithRawResponse:
    def __init__(self, schools: AsyncSchoolsResource) -> None:
        self._schools = schools

        self.retrieve = async_to_raw_response_wrapper(
            schools.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            schools.list,
        )
        self.by_authority = async_to_raw_response_wrapper(
            schools.by_authority,
        )
        self.by_city = async_to_raw_response_wrapper(
            schools.by_city,
        )
        self.by_status = async_to_raw_response_wrapper(
            schools.by_status,
        )
        self.by_suburb = async_to_raw_response_wrapper(
            schools.by_suburb,
        )
        self.search = async_to_raw_response_wrapper(
            schools.search,
        )


class SchoolsResourceWithStreamingResponse:
    def __init__(self, schools: SchoolsResource) -> None:
        self._schools = schools

        self.retrieve = to_streamed_response_wrapper(
            schools.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            schools.list,
        )
        self.by_authority = to_streamed_response_wrapper(
            schools.by_authority,
        )
        self.by_city = to_streamed_response_wrapper(
            schools.by_city,
        )
        self.by_status = to_streamed_response_wrapper(
            schools.by_status,
        )
        self.by_suburb = to_streamed_response_wrapper(
            schools.by_suburb,
        )
        self.search = to_streamed_response_wrapper(
            schools.search,
        )


class AsyncSchoolsResourceWithStreamingResponse:
    def __init__(self, schools: AsyncSchoolsResource) -> None:
        self._schools = schools

        self.retrieve = async_to_streamed_response_wrapper(
            schools.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            schools.list,
        )
        self.by_authority = async_to_streamed_response_wrapper(
            schools.by_authority,
        )
        self.by_city = async_to_streamed_response_wrapper(
            schools.by_city,
        )
        self.by_status = async_to_streamed_response_wrapper(
            schools.by_status,
        )
        self.by_suburb = async_to_streamed_response_wrapper(
            schools.by_suburb,
        )
        self.search = async_to_streamed_response_wrapper(
            schools.search,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SchoolListParams"]


class SchoolListParams(TypedDict, total=False):
    authority: str
    """Filter by education authority"""

    city: str
    """Filter by city (partial match)"""

    limit: int
    """Results per page (default: 20, max: 100)"""

    name: str
    """Filter by school name (partial match)"""

    org_type: str
    """Filter by organization type"""

    page: int
    """Page number (default: 1)"""

    status: str
    """Filter by school status"""

    suburb: str
    """Filter by suburb (partial match)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.sync_trigger_response import SyncTriggerResponse
from ..types.sync_get_status_response import SyncGetStatusResponse

__all__ = ["SyncResource", "AsyncSyncResource"]


class SyncResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SyncResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/et0and/schools-sdk-python#accessing-raw-response-data-eg-headers
        """
        return SyncResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SyncResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/et0and/schools-sdk-python#with_streaming_response
        """
        return SyncResourceWithStreamingResponse(self)

    def get_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncGetStatusResponse:
        """Get sync status"""
        return self._get(
            "/v1/sync/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SyncGetStatusResponse,
        )

    def trigger(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncTriggerResponse:
        """Trigger manual data sync"""
        return self._post(
            "/v1/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SyncTriggerResponse,
        )


class AsyncSyncResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSyncResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/et0and/schools-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSyncResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSyncResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/et0and/schools-sdk-python#with_streaming_response
        """
        return AsyncSyncResourceWithStreamingResponse(self)

    async def get_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncGetStatusResponse:
        """Get sync status"""
        return await self._get(
            "/v1/sync/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SyncGetStatusResponse,
        )

    async def trigger(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncTriggerResponse:
        """Trigger manual data sync"""
        return await self._post(
            "/v1/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SyncTriggerResponse,
        )


class SyncResourceWithRawResponse:
    def __init__(self, sync: SyncResource) -> None:
        self._sync = sync

        self.get_status = to_raw_response_wrapper(
            sync.get_status,
        )
        self.trigger = to_raw_response_wrapper(
            sync.trigger,
        )


class AsyncSyncResourceWithRawResponse:
    def __init__(self, sync: AsyncSyncResource) -> None:
        self._sync = sync

        self.get_status = async_to_raw_response_wrapper(
            sync.get_status,
        )
        self.trigger = async_to_raw_response_wrapper(
            sync.trigger,
        )


class SyncResourceWithStreamingResponse:
    def __init__(self, sync: SyncResource) -> None:
        self._sync = sync

        self.get_status = to_streamed_response_wrapper(
            sync.get_status,
        )
        self.trigger = to_streamed_response_wrapper(
            sync.trigger,
        )


class AsyncSyncResourceWithStreamingResponse:
    def __init__(self, sync: AsyncSyncResource) -> None:
        self._sync = sync

        self.get_status = async_to_streamed_response_wrapper(
            sync.get_status,
        )
        self.trigger = async_to_streamed_response_wrapper(
            sync.trigger,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from schools import Schools, AsyncSchools
from tests.utils import assert_matches_type
from schools.types import (
    SchoolListResponse,
    SchoolSearchResponse,
    SchoolRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSchools:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Schools) -> None:
        school = client.schools.retrieve(
            "schoolId",
        )
        assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Schools) -> None:
        response = client.schools.with_raw_response.retrieve(
            "schoolId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Schools) -> None:
        with client.schools.with_streaming_response.retrieve(
            "schoolId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Schools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `school_id` but received ''"):
            client.schools.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Schools) -> None:
        school = client.schools.list()
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Schools) -> None:
        school = client.schools.list(
            authority="authority",
            city="city",
            limit=1,
            name="name",
            org_type="org_type",
            page=1,
            status="status",
            suburb="suburb",
        )
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Schools) -> None:
        response = client.schools.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Schools) -> None:
        with client.schools.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert_matches_type(SchoolListResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_authority(self, client: Schools) -> None:
        school = client.schools.by_authority(
            authority="authority",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_authority_with_all_params(self, client: Schools) -> None:
        school = client.schools.by_authority(
            authority="authority",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_by_authority(self, client: Schools) -> None:
        response = client.schools.with_raw_response.by_authority(
            authority="authority",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_by_authority(self, client: Schools) -> None:
        with client.schools.with_streaming_response.by_authority(
            authority="authority",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_by_authority(self, client: Schools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `authority` but received ''"):
            client.schools.with_raw_response.by_authority(
                authority="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_city(self, client: Schools) -> None:
        school = client.schools.by_city(
            city="city",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_city_with_all_params(self, client: Schools) -> None:
        school = client.schools.by_city(
            city="city",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_by_city(self, client: Schools) -> None:
        response = client.schools.with_raw_response.by_city(
            city="city",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_by_city(self, client: Schools) -> None:
        with client.schools.with_streaming_response.by_city(
            city="city",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_by_city(self, client: Schools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `city` but received ''"):
            client.schools.with_raw_response.by_city(
                city="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_status(self, client: Schools) -> None:
        school = client.schools.by_status(
            status="status",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_status_with_all_params(self, client: Schools) -> None:
        school = client.schools.by_status(
            status="status",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_by_status(self, client: Schools) -> None:
        response = client.schools.with_raw_response.by_status(
            status="status",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_by_status(self, client: Schools) -> None:
        with client.schools.with_streaming_response.by_status(
            status="status",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_by_status(self, client: Schools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `status` but received ''"):
            client.schools.with_raw_response.by_status(
                status="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_suburb(self, client: Schools) -> None:
        school = client.schools.by_suburb(
            suburb="suburb",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_by_suburb_with_all_params(self, client: Schools) -> None:
        school = client.schools.by_suburb(
            suburb="suburb",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_by_suburb(self, client: Schools) -> None:
        response = client.schools.with_raw_response.by_suburb(
            suburb="suburb",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_by_suburb(self, client: Schools) -> None:
        with client.schools.with_streaming_response.by_suburb(
            suburb="suburb",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_by_suburb(self, client: Schools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `suburb` but received ''"):
            client.schools.with_raw_response.by_suburb(
                suburb="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search(self, client: Schools) -> None:
        school = client.schools.search(
            q="x",
        )
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search_with_all_params(self, client: Schools) -> None:
        school = client.schools.search(
            q="x",
            limit=1,
            page=1,
        )
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_search(self, client: Schools) -> None:
        response = client.schools.with_raw_response.search(
            q="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = response.parse()
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_search(self, client: Schools) -> None:
        with client.schools.with_streaming_response.search(
            q="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = response.parse()
            assert_matches_type(SchoolSearchResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSchools:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.retrieve(
            "schoolId",
        )
        assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.retrieve(
            "schoolId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.retrieve(
            "schoolId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert_matches_type(SchoolRetrieveResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSchools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `school_id` but received ''"):
            await async_client.schools.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.list()
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.list(
            authority="authority",
            city="city",
            limit=1,
            name="name",
            org_type="org_type",
            page=1,
            status="status",
            suburb="suburb",
        )
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert_matches_type(SchoolListResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert_matches_type(SchoolListResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_authority(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_authority(
            authority="authority",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_authority_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_authority(
            authority="authority",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_by_authority(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.by_authority(
            authority="authority",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_by_authority(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.by_authority(
            authority="authority",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_by_authority(self, async_client: AsyncSchools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `authority` but received ''"):
            await async_client.schools.with_raw_response.by_authority(
                authority="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_city(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_city(
            city="city",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_city_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_city(
            city="city",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_by_city(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.by_city(
            city="city",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_by_city(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.by_city(
            city="city",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_by_city(self, async_client: AsyncSchools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `city` but received ''"):
            await async_client.schools.with_raw_response.by_city(
                city="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_status(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_status(
            status="status",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_status_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_status(
            status="status",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_by_status(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.by_status(
            status="status",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_by_status(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.by_status(
            status="status",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_by_status(self, async_client: AsyncSchools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `status` but received ''"):
            await async_client.schools.with_raw_response.by_status(
                status="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_suburb(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_suburb(
            suburb="suburb",
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_by_suburb_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.by_suburb(
            suburb="suburb",
            limit=1,
            page=1,
        )
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_by_suburb(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.by_suburb(
            suburb="suburb",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert school is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_by_suburb(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.by_suburb(
            suburb="suburb",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert school is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_by_suburb(self, async_client: AsyncSchools) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `suburb` but received ''"):
            await async_client.schools.with_raw_response.by_suburb(
                suburb="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.search(
            q="x",
        )
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncSchools) -> None:
        school = await async_client.schools.search(
            q="x",
            limit=1,
            page=1,
        )
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_search(self, async_client: AsyncSchools) -> None:
        response = await async_client.schools.with_raw_response.search(
            q="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        school = await response.parse()
        assert_matches_type(SchoolSearchResponse, school, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncSchools) -> None:
        async with async_client.schools.with_streaming_response.search(
            q="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            school = await response.parse()
            assert_matches_type(SchoolSearchResponse, school, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["RootRetrieveResponse"]


class RootRetrieveResponse(BaseModel):
    docs: Optional[str] = None

    endpoints: Optional[object] = None

    message: Optional[str] = None

    version: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .school_list_params import SchoolListParams as SchoolListParams
from .school_list_response import SchoolListResponse as SchoolListResponse
from .school_search_params import SchoolSearchParams as SchoolSearchParams
from .health_check_response import HealthCheckResponse as HealthCheckResponse
from .school_by_city_params import SchoolByCityParams as SchoolByCityParams
from .sync_trigger_response import SyncTriggerResponse as SyncTriggerResponse
from .root_retrieve_response import RootRetrieveResponse as RootRetrieveResponse
from .school_search_response import SchoolSearchResponse as SchoolSearchResponse
from .school_by_status_params import SchoolByStatusParams as SchoolByStatusParams
from .school_by_suburb_params import SchoolBySuburbParams as SchoolBySuburbParams
from .school_retrieve_response import SchoolRetrieveResponse as SchoolRetrieveResponse
from .sync_get_status_response import SyncGetStatusResponse as SyncGetStatusResponse
from .school_by_authority_params import SchoolByAuthorityParams as SchoolByAuthorityParams
